% This program creates a synthetic model for the Nephi PhD project

clear all;close all;

load vfinal_test.mat  % load vfinal.mat created for synthetic testing (0.5m grid)
load vfinal.mat       % load true vfinal.mat for comparison
load raypath.mat      % load true raypath.mat for comparison

[nz nx] = size(vfinal_test);
vsynth = ones(nz,nx);
vsynth = vsynth*333;  % set to air velocity
vmax = 2300;  % maximum velocity at the bottom of the model
vmin = 500;   % minimum velocity at the top of the model

vgrad = (vmax-vmin)/nz;

for ix = 1:nx
    for iz = 1:nz
        if vfinal_test(iz,ix) > 333
            elev(ix) = iz;
            break
        end
    end
end

for ix = 1:nx
    vtmp(1:nz+1-elev(ix),1) = (vmin + vgrad* [1:(nz+1-elev(ix))])';
    vsynth(elev(ix):nz,ix) = vtmp;
    clear vtmp;
end

alpha = 55*pi/180;  % set here the dip angle (from horizontal) of all subsequent faults
fgrad = tan(alpha);

%fault 1
f1x = 110;  % grid position at ground surface (not top of model)
[synmodel4] = faultadd(f1x,fgrad,20*vgrad,vsynth,elev);  % note, "15" indicates the degree to
																				% which velocity increases laterally																				% across the fault.  90 m/s is being																				% to the upthrown side.
%fault 2																		% across the fault.  150 m/s is being
%f2x = 80;																	% added to every pixel on the upthrown
%[fault] = faultadd(f2x,fgrad,9*vgrad,fault,elev);	% side.

%fault3
%f3x = 115;
%[fault] = faultadd(f3x,fgrad,16*vgrad,fault,elev);


% antithetic faults are being created here, which will truncate against normal faults if encountered
%fgrad = -tan(alpha);

% fault 4
%f4x = 200;
%[fault] = faultadd(f4x,fgrad,12*vgrad,fault,elev,f3x);
       
% fault 5
%f5x = 275;
%[fault] = faultadd(f5x,fgrad,9*vgrad,fault,elev,f3x);

% fault 6
%f6x = 320;
%[fault] = faultadd(f6x,fgrad,9*vgrad,fault,elev,f3x);

for ix = 1:nx
    synmodel4(1:elev(ix)-1,ix) = 333; % use air velocity
end

save synmodel4 synmodel4

RP(:,2) = [1:1:nx]';
RP(:,1) = elev(RP(:,2))';
src = RP;

figure;
subplot(311);imagesc(vfinal,[0 2200]);colorbar;
subplot(312);imagesc(raypath,[0 2000]);colorbar;
subplot(313);imagesc(synmodel4,[0 2200]);colorbar;hold on;
plot(RP(:,2),RP(:,1),'r*');plot(src(:,2),src(:,1),'y+')

