clear
close all

% This program creates the "coord.temp" file read into the Matlab tomographic program.  It was used for the Judge
% High School experiment where the survey configuration was 120 geophones 2' apart and a shot point at every geophone.
% Reciprocity and time shifting was used.

% SET THE QC CUTOFF HERE 
% (may want to change this: it's dependent on the period of the first arrivals) 
%  cutoff = T/4 (about)
cutoff=.004;		% in sec
% ALL PICKS WITH A RECIPRICITY ERROR GREATER THAN cutoff WILL BE SET TO ZERO


% LOAD THE ELEVATION VARIABLES
load elev.txt
offset=elev(:,1);
elevation=elev(:,2);
elevation=max(elevation)-elevation;
SX=[0:2:238]'; 	% shot X (m)
SZ=spline(offset,elevation,SX); % shot Z (m)
SN=[1:120]'; 		% shot number
RN=[1:120]';   	% receiver number
RX=[0:2:238]'; 	% receiver X (m)
RZ=SZ;				% receiver Z (m)

% PLOT THE ELEVATIONS
figure(1);
subplot(2,1,1)
plot(SX,SZ)
hold on
plot(offset,elevation,'r*')
title('Cubic Spline Interpolation of Relative Elevations (Vertical Exaguration)')
xlabel('Offset (ft)')
ylabel('Relative Elevation (ft)')
subplot(2,1,2)
plot(SX,SZ)
hold on
plot(offset,elevation,'r*')
title('Cubic Spline Interpolation of Relative Elevations (No Vertical Exageration)')
xlabel('Offset (ft)')
ylabel('Relative Elevation (ft)')
axis equal
print -djpeg100 elevation.jpg


% LOAD THE TRAVELTIME PICKS (from VISTA)
% data_name.fbp is the output from VISTA
% make sure you change the name in both of the following lines to your data file name.
load data_name.fbp
FBP=data_name;
sn=FBP(:,2);  	% shot number
rn=FBP(:,4);  	% receiver number
tt=FBP(:,5);	% traveltime (ms)

% CONVERT PICK units from milliseconds to seconds
TT=tt/1000;	% Traveltime in seconds
% SHIFT THE TRAVELTIME MATRIX BY 0.008 sec TO ACCOUNT FOR PICKING THE PEAK
%TT=TT-.008;
% Zero all negative time picks
for i=1:length(TT)
	if TT(i)<0
		TT(i)=0;
	end
end


% MAKE THE TRAVELTIME MATRIX
%	SHOT NUMBER IS HORIZONTAL AXIS
%	RECEIVER NUMBER IS VERTICAL AXIS
SNM=max(sn);
RNM=max(rn);
ttmat=zeros(RNM,SNM);
for i=1:length(TT)
	ttmat(rn(i),sn(i))=TT(i);
end

% GENERATE AN IMAGE
figure;imagesc(ttmat);colorbar;axis image;title('Traveltime Matrix')
xlabel('Source Number');ylabel('Receiver Number')
print -djpeg100 traveltime.jpg

% (SHOTS AT A RECEIVER) FOR RECIPROCITY
ttmat_rec=ttmat;

% CALCULATE RECIPOCAL ERROR
up=triu(ttmat_rec);
lo=tril(ttmat_rec)';
% % FILL IN THE HOLES
% for i=1:120
% for j=i:120
%	if (up(i,j)==0) & (lo(i,j)~=0)
%		up(i,j)=lo(i,j);
%	elseif (lo(i,j)==0) & (up(i,j)~=0)
%		lo(i,j)=up(i,j);
%	end
% end
% end
diff=up-lo;
d2=diff-diff';
figure;imagesc(d2);colorbar;axis image;title('Traveltime Error')
xlabel('Source Number');ylabel('Receiver Number') 
print -djpeg100 recip_error.jpg

% Histogram of traveltime reciprocal errors
vd2=d2(:);figure;hist(vd2,100)
title('Traveltime Error Histogram');xlabel('Traveltime Error');ylabel('Number') 
print -djpeg100 histogram.jpg

% REMOVE ALL TRAVELTIMES WITH RECIPROCAL ERROR GREATER THAN cutoff 
%   OR BOTH PICKS HAVE TRAVELTIMES OF ZERO
count=0;
index=triu(ones(120,120));
tt=(up+lo)/2;
for i=1:120
for j=i:120
	if (abs(diff(i,j)) >= cutoff) | ((tt(i,j)==0) & (tt(j,i) == 0))
		tt(i,j)=0;
		index(i,j)=0;
	end
end
end
index=index+index';
tt=tt+tt';
for i=1:120
	tt(i,i)=up(i,i);
	index(i,i)=1;
end



figure;imagesc(tt);colorbar;axis image;
title('Traveltime Matrix After Reciprocity Rejection')
xlabel('Source Number');ylabel('Receiver Number')
print -djpeg100 traveltime_new.jpg

reject=120*120 - sum(sum(index));
perc_rej=reject*100/(120*120);
figure;c=[0 0 0;1 1 1];imagesc(index);colormap(c);axis image
title('Rejected Traveltime Picks (Black)')
xlabel('Source Number');ylabel('Receiver Number')
print -djpeg100 rejected.jpg



[M,N]=size(ttmat);
clear index
index=ones(M,N);
for i=1:M
for j=1:N
	if ttmat(i,j)==0
		index(i,j)=0;
	end
end
end

% DETERMINE THE NUMBER OF TRAVELTIME PER SHOT
num_rec=sum(index,1)';
figure;plot(num_rec,'b*');title('Number of Traveltime picks per shot')
xlabel('Shot Number');ylabel('Number of Picks')
print -djpeg100 picks_shot.jpg
            
% MAKE coord.temp SOURCE VALUES
src_num=[1:SNM]';	% Source number 
mSZ=min(SZ);
SZ=SZ-mSZ;
SOURCE=[src_num SX SZ num_rec];

% MAKE coord.temp RECEIVER VALUES
rx=RX;
rz=RZ-mSZ;
count=1;
for i=1:SNM
for j=1:RNM
        if index(j,i)==1
                rec_x(count)=rx(j);
                rec_z(count)=rz(j);
                rec_tt(count)=ttmat(j,i);
                pq(count)=1;
                count=count+1;
        end
end
end
RECEIVER=[rec_x' rec_z' rec_tt' pq'];

          

% MAKE HEADER VALUES
xmin=0;
xmax=max(SX);
zmin=min(SZ);
%  Change the following line
zmax=40;			% total depth of model
emax=max(SZ);	% elevation change over line 
nmr=max(RN);
HEADER=[SNM xmin xmax xmax-xmin zmin
	zmax emax nmr 0 0];


% SAVE AND WRITE coord.temp
fid=fopen('coord.temp','w');
fprintf(fid,'%5d %5.1f %5.1f %5.1f %5.1f\n',HEADER(1,:)');
fprintf(fid,'%5.3f %5.1f %5d\n',HEADER(2,1:3)');
fprintf(fid,'%5d %5.2f %5.2f %5d\n',SOURCE');
fprintf(fid,'%5.2f %5.2f %5.5f %5.1f\n',RECEIVER');
fclose(fid);
	

