clear
close all

% This program creates the "coord.temp" file that converts Vista's .fbp file into something that can be read into
% the Matlab tomographic program.  The survey geometry is for shot points in between geophones and includes
% reciprocity.

% SET THE QC CUTOFF HERE 
cutoff=.004;
% ALL PICKS WITH A RECIPRICITY ERROR GREATER THAN cutoff WILL BE SET TO ZERO



% LOAD THE ELEVATION VARIABLES (from EXCEL space delimited)
load line2_elev.ascii
elev=line2_elev;
SN=elev(:,1); 	% shot number
SX=elev(:,2); 	% shot X (m)
SZ=elev(:,4); 	% shot Z (m)
RN=[1:120]';    % receiver number
RX=RN-1; 	% receiver X (m)
for i=1:2:239
RZ((i+1)/2)=SZ(i);% receiver Z (m)
end

% LOAD THE TRAVELTIME PICKS (from VISTA)
load Line2.fbp
sn=Line2(:,2);  % shot number
rn=Line2(:,4);  % receiver number
tt=Line2(:,5);	% traveltime (ms)

% CONVERT PICKS TO MKS UNITS
TT=tt/1000;	% Traveltime in seconds
% SHIFT THE TRAVELTIME MATRIX BY 0.008 sec TO ACCOUNT FOR PICKING THE PEAK
TT=TT-.008;
for i=1:length(TT)
	if TT(i)<0
		TT(i)=0;
	end
end


% MAKE THE TRAVELTIME MATRIX
%	SHOT NUMBER IS HORIZONTAL AXIS
%	RECEIVER NUMBER IS VERTICAL AXIS
SNM=max(sn);
RNM=max(rn);
ttmat=zeros(RNM,SNM);
for i=1:length(TT)
	ttmat(rn(i),sn(i))=TT(i);
end
ttmat(111,227)=0;

% GENERATE AN IMAGE
imagesc(ttmat);colorbar;axis image;title('Traveltime Matrix')
xlabel('Source Number');ylabel('Receiver Number')

% JUST USE THE ODD SOURCE NUMBERS (SHOTS AT A RECEIVER) FOR RECIPROCITY
ttmat_rec=zeros(120);
for j=1:2:239
	ttmat_rec(:,(j+1)/2)=ttmat(:,j);
end

% CALCULATE RECIPOCAL ERROR
up=triu(ttmat_rec);
lo=tril(ttmat_rec)';
 % FILL IN THE HOLES
 for i=1:120
 for j=i:120
	if (up(i,j)==0) & (lo(i,j)~=0)
		up(i,j)=lo(i,j);
	elseif (lo(i,j)==0) & (up(i,j)~=0)
		lo(i,j)=up(i,j);
	end
 end
 end
diff=up-lo;
d2=diff+diff';
figure;imagesc(d2);colorbar;axis image;title('Traveltime Error')
xlabel('Source Number');ylabel('Receiver Number') 

% Histogram of traveltime reciprocal errors
vd2=d2(:);figure;hist(vd2,100)
title('Traveltime Error Histogram');xlabel('Traveltime Error');ylabel('Number') 

% REMOVE ALL TRAVELTIMES WITH RECIPROCAL ERROR GREATER THAN cutoff
count=0;
index=triu(ones(120,120));
tt=(up+lo)/2;
for i=1:120
for j=i:120
	if abs(diff(i,j)) >= cutoff
		tt(i,j)=0;
		index(i,j)=0;
	end
end
end
index=index+index';
tt=tt+tt';
for i=1:120
	tt(i,i)=up(i,i);
	index(i,i)=1;
end



%for j=79:96
%	tt(:,j)=0;
%end



figure;imagesc(tt);colorbar;axis image;
title('Traveltime Matrix After Reciprocity Rejection')
xlabel('Source Number');ylabel('Receiver Number')
reject=120*120 - sum(sum(index));
perc_rej=reject*100/(120*120);
figure;c=[0 0 0;1 1 1];imagesc(index);colormap(c);axis image
title('Rejected Traveltime Picks (Black)')
xlabel('Source Number');ylabel('Receiver Number')
for j=79:96
	index(:,j)=0;
end
for j=1:2:239
	ttmat(:,j)=tt(:,(j+1)/2);
end


[M,N]=size(ttmat);
clear index
index=ones(M,N);
for i=1:M
for j=1:N
	if ttmat(i,j)==0
		index(i,j)=0;
	end
end
end

% DETERMINE THE NUMBER OF TRAVELTIME PER SHOT
num_rec=sum(index,1)';
figure;plot(num_rec,'b*');title('Number of Traveltime picks per shot')
xlabel('Shot Number');ylabel('Number of Picks')
            
% MAKE coord.temp SOURCE VALUES
src_num=[1:SNM]';	% Source number 
mSZ=min(SZ);
SZ=SZ-mSZ;
SOURCE=[src_num SX SZ num_rec];

% MAKE coord.temp RECEIVER VALUES
rx=RX;
rz=RZ-mSZ;
count=1;
for i=1:SNM
for j=1:RNM
        if index(j,i)==1
                rec_x(count)=rx(j);
                rec_z(count)=rz(j);
                rec_tt(count)=ttmat(j,i);
                pq(count)=1;
                count=count+1;
        end
end
end
RECEIVER=[rec_x' rec_z' rec_tt' pq'];

          

% MAKE HEADER VALUES
xmin=0;
xmax=max(SX);
zmin=min(SZ);
zmax=40;	% total depth of model
emax=max(SZ);		% elevation change over line 
nmr=120;
HEADER=[SNM xmin xmax xmax-xmin zmin
	zmax emax nmr 0 0];


% SAVE AND WRITE coord.temp
%save SOURCE SOURCE -ascii
%save RECEIVER RECEIVER -ascii
fid=fopen('HEADER.txt','w');
fprintf(fid,'%5d %5.1f %5.1f %5.1f %5.1f\n',HEADER(1,:)');
fprintf(fid,'%5.3f %5.1f %5d\n',HEADER(2,1:3)');
fclose(fid);
fid=fopen('SOURCE.txt','w');
fprintf(fid,'%5d %5.2f %5.2f %5d\n',SOURCE');
fclose(fid);
fid=fopen('RECEIVER.txt','w');
fprintf(fid,'%5.2f %5.2f %5.5f %5.1f\n',RECEIVER');
fclose(fid);
!cat HEADER.txt SOURCE.txt RECEIVER.txt > coord.temp_qc
!rm HEADER.txt SOURCE.txt RECEIVER.txt


	

