function [freq,db]=filterspec(datain,tr1,tr2,t1,t2,rec,pltflg,axeshandle)
%
%
%ASPEC draws the amplitude spectrum of a seismic record
%
%
%function [db]=aspec(data,data_dhm,win2,pltflg)
%
%INPUT VARIABLES
%data=		seismic data
%smp=		time sampling interval in sec
%win2=		vector containing the time and the trace window of the data to be analysed
%		format [trace1 trace2 time1 time2]
%pltflg= 	plotting parameter
%	1= amplitude in dB
%	2= amplitude
%	3= log10 of the amplitude
%axeshandle=    axes handle for amplitude spectrum plotting
%
%OUTPUT VARIABLES
%db=	amplitude spectrum
%Copy from DSI function [freq,db]=aspecomputem(datain,tr1,tr2,t1,t2,rec,pltflg)
% Modified by Min Zhou, 09/09/99

smp=datain.fh{8};
t1=round((t1-datain.fh{9})./smp+1);
t2=round((t2-datain.fh{9})./smp+1);
tr=[tr1 tr2];
tr1=min(tr);
tr2=max(tr);

n=(t2-t1)+1;
rads=(180/pi);
rn2=round(n/2);
Y=zeros((t2-t1)+1,(tr2-tr1)+1);

  for i=tr1:tr2
    Y(:,i-tr1+1) = fft(datain.dat{rec}(t1:t2,i));
  end

avrg=mean(Y')';

phase=atan(imag(avrg)./real(avrg));
phase=phase(1:rn2).*rads;

amp = abs(avrg(1:rn2));
db=20*log10(abs(amp));
nyquist = 1/(2*smp);
freq = (1:rn2)/rn2*nyquist;

if pltflg==1
%   set(gcf,'CurrentAxes',axeshandle)
   subplot(axeshandle)

   plot(freq,db,'-b')
   xlabel('Frequency Hz')
   ylabel('Amplitude dB')
   title('Amplitude Spectrum')
   grid on

elseif pltflg==2
%   set(gcf,'CurrentAxes',axeshandle)
   subplot(axeshandle)

   plot(freq,amp/100,'-r')
   xlabel('Frequency Hz')
   ylabel('Amplitude')
   title('Amplitude Spectrum')
   grid on

else
%   set(gcf,'CurrentAxes',axeshandle)
   subplot(axeshandle)

   plot(freq,log10(amp),'-g')
   xlabel('Frequency Hz')
   ylabel('Amplitude')
   title('Amplitude Spectrum')
   grid on
end

