function smooth(num_smooth,No_smooth)

%
%function smooth
%Set smooth schedule
%Input: num_smooth -- Total number of smooth 
%       No_smooth  -- Number of smooth presently working on
%
%Modifies to function by Min Zhou, 09/30/99
%

if nargin<2
  No_smooth=1;
end %if

h=findobj('Name','Xwell Refraction Inversion Main');
user=get(h,'userdata');
unit1=user.unit1; unit2=user.unit2;

fig_name=['Smooth Schedule No.',num2str(No_smooth)];
figure('Position',[200 200 560 420],'Name',fig_name,...
       'MenuBar','none','NumberTitle','off','resize','off');

file_name=['sch_',num2str(No_smooth),'.in'];
ff=fopen(file_name,'r');
if ff ~= -1
	line=fgets(ff);a=sscanf(line,'%f');
	key=round(a(1));iter=round(a(2));dx=a(3);
	line=fgets(ff);a=sscanf(line,'%f');
	vmin=a(1);vmax=a(2);
	line=fgets(ff);a=sscanf(line,'%f');
	v1=a(1);v2=a(2);
	line=fgets(ff);a=sscanf(line,'%f');
	irsx=round(a(1));irsz=round(a(2));
	line=fgets(ff);a=sscanf(line,'%f');
	nite=round(a(1));ndown=round(a(2));
	fclose(ff);
end

wordwin=['Input parameter file #',num2str(No_smooth)];
uicontrol('Style','Pushbutton','String',wordwin,...
          'Position',[100,360,400,50]);

sss=num2str(iter);
uicontrol('Style','Pushbutton',...
          'String','Iteration',...
          'Position',[80 300 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[180 300 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','Iterationtext');

sss=num2str(dx);
uicontrol('Style','Pushbutton',...
          'String',['Grid spacing',unit1],...
          'Position',[350 300 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[450 300 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','gridtext');
             
sss=num2str(v1);
uicontrol('Style','Pushbutton',...
          'String',['Vtop',unit2],...
          'Position',[80 250 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[180 250 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','vtoptext');

sss=num2str(v2);
uicontrol('Style','Pushbutton',...
          'String',['Vbottom',unit2],...
          'Position',[350 250 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[450 250 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','vbottomtext');

sss=num2str(vmin);
uicontrol('Style','Pushbutton',...
          'String',['Vmin',unit2],...
          'Position',[80 200 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[180 200 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','minvtext');

sss=num2str(vmax);
uicontrol('Style','Pushbutton',...
          'String',['Vmax',unit2],...
          'Position',[350 200 100 30]);
uicontrol('Style','edit','String',sss,...
          'Position',[450 200 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','maxvtext');

sss=num2str(nite);
uicontrol('Style','Pushbutton',...
          'String','Nite(# of shoots)',...
          'Position',[80 150 100 30]);  
uicontrol('Style','edit','String',sss,...
          'Position',[180 150 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','Nitetext');

sss=num2str(ndown);
uicontrol('Style','Pushbutton',...
          'String','Ndown',...
          'Position',[350 150 100 30]); 
uicontrol('Style','edit','String',sss,...
          'Position',[450 150 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','Ndowntext');

sss=num2str(irsx);
uicontrol('Style','Pushbutton',...
               'String','Irsx(grid points)',...
               'Position',[80 100 100 30]);  
uicontrol('Style','edit','String',sss,...
          'Position',[180 100 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','Irsxtext');

sss=num2str(irsz);
uicontrol('Style','Pushbutton',...
          'String','Irsz(grid points)',...
          'Position',[350 100 100 30]); 
uicontrol('Style','edit','String',sss,...
          'Position',[450 100 70 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','Irsztext');
                                    
paramok_smooth=['paramok_',num2str(No_smooth)];

callstr=['smoothok(',num2str(num_smooth),',',num2str(No_smooth),',',num2str(key),');'];

hlpstr=['tt={'' '';''Smoothing Parameters'';'' '';',...
        '''    Iteration: The iteration number in this smooth size.'';',...
        ''' '';''    Grid Spacing: The size of the grid in inversion, ',...
        'in (m) or (ft).'';'' '';''    Vtop: Initial guess of velocity ',...
        'for top layer, (m/sec) or (ft/sec).'';'' '';',...
        '''    Vbottom: Initial guess of velocity for bottom layer.'';',...
        ''' '';''    Vmin: Minumum velocity allowed in inversion.'';',...
        ''' '';''    Vmax: Maximum velocity allowed in inversion.'';',...
        ''' '';''    Nite: # of shots used to calculates the step length.'';'...
        ''' '';''    Ndown: =1, downward extrapolation of gradient;',...
        '  =2, slowness.'';',...
        ''' '';''    Irsx: Half size of horizontal smoothing ',...
        'operator in # of grid points.'';'' '';',...
        '''    Irsz: Half size of vertical smoothing operator in ',...
        '# of grid points.''};',...
        'h=msgbox(tt,''Smoothing Parameters'');',...
        'set(findobj(h,''Style'',''text''),''backgroundcolor'',[1 1 1]);'];


%pay attention to such problem, in callback, all the variables
%in function are not available. Found on 10/03/99

uicontrol('Style','pushbutton','String','Help',...
          'Position',[100 50 80 30],...
          'Callback',hlpstr);
uicontrol('Style','Pushbutton','String','OK',...
          'Position',[260 50 50 30],...
          'Callback',callstr);
uicontrol('Style','Pushbutton',...
          'String','Cancel',...
          'Position',[390 50 80 30],...
          'Callback','close(gcf)');   
