function syn_draw(action)

%
%function syn_draw
%Draw a wedge in velocity model and set wedge velocity
%called by syn_show.m
%

if ~nargin
 action='draw';
end

switch action

case 'draw'
h=findobj('Name','Velocity Model for Forward Modeling');
figure(h);

hold on;
max_points=1000;
for i=1:max_points
    [x,y,b]=ginput(1);
    if b ~= 1;
         px(i)=px(1);py(i)=py(1);plot(px(1:i),py(1:i));
         hold off;
         a=get(gcf,'userdata');
         a.px=px;a.py=py;
         set(gcf,'userdata',a); %set [px py] for further use
         return;
    end;
    if b == 1
	px(i)=x;
	py(i)=y;
	plot(px(1:i),py(1:i));
    end;
end;

case 'set'
a=get(gcbf,'userdata');
figure('Position',[200 200 400 200],...
       'Menubar','none',...
       'NumberTitle','off','Resize','off',...
       'Name','Save Wedge');

uicontrol('Style','Pushbutton',...
          'String',['Input the Wedge Velocity ',a.unit2],...
          'Position',[100 150 200 30]);

uicontrol('Style','edit','String','500',...
          'Position',[150 100 100 30],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','wedgeveltext');

uicontrol('Style','Pushbutton',...
          'String','OK',...
          'Position',[175 40 50 30],...
          'Callback','syn_draw setok');

case 'setok'
vel_wedge=str2num(get(findobj(gcbf,'Tag','wedgeveltext'),'string'));
close(gcbf);

h=findobj('Name','Velocity Model for Forward Modeling');

figure(h);
clearstr=['delete(findobj(gcf,''Style'',''pushbutton''));',...
          'delete(findobj(gcf,''Style'',''edit''));',...
          'delete(findobj(gcf,''Type'',''axes''));'];
eval(clearstr);

%change velocity model
load slow.mat;
v_syn=1./slow;

a=get(h,'userdata');
px=a.px; py=a.py; dx=a.dx;
[nz,nx]=size(slow);
if nz~=a.nz | nx~=a.nx
 error('The size of the model does not consist.')
end
xx=[0:dx:(nx-1)*dx];zz=[0:dx:(nz-1)*dx];
xmin=min(px(:));xmax=max(px(:));
ymin=min(py(:));ymax=max(py(:));
for i=1:nz
for j=1:nx
	x=(j)*dx;y=(i)*dx;
	if x >= xmin & x <= xmax & y >= ymin & y <= ymax
	[isin]=in_or_out(px,py,x,y);
	if isin == 1
		v_syn(i,j)=vel_wedge;
	end
	end
end;
end;

imagesc(xx,zz,v_syn);
colorbar;
xlabel(['Offset ',a.unit1]);
ylabel(['Depth ',a.unit1]);
title('Velocity Model');
text((nx-1)*dx+(nx-1)*dx/670*100,-(nz-1)*dx/20,a.unit2(2:length(a.unit2)-1));

a.v_syn=v_syn;
a.set=1; % set set velocity flag
set(h,'userdat',a); %set velocity data to userdata


case 'save'
a=get(gcbf,'userdata');
if a.set==1 
  slow=1./a.v_syn;
  save slow.dat slow -ascii;
  a.set==0; % set set velocity flag to 0
%  [s10,w10]=unix('t4 < slow_asc2for.in >tmp');
% Modified by Min Zhou , 10/26/99 
  fid=fopen('slowsave.in','w');
  [nraw,ncol]=size(slow);
  fprintf(fid,'%d %d\n',nraw,ncol);
  fclose(fid);
  [s10,w10]=unix('slowasc_for');
end %if
% There is not need for save for slow if the wedge was not set.

  [s10,w10]=unix('echo slow has been updated.');
figure(gcbf);
uicontrol('Style','pushbutton',...
          'String','Velocity has been updated.',...
          'Position',[150 250 300 50],...
          'BackGroundColor','w',...
          'ForeGroundColor','r',...
          'Tag','ww');
pause(1);
delete(findobj(gcf,'Tag','ww'));

case 'cancel'
load slow.mat;
v_syn=1./slow;
[nz,nx]=size(slow);
ff=fopen('refra-2d.in','r');
line=fgets(ff);a=sscanf(line,'%f');
dx=a(3);
fclose(ff);

figure(gcbf);
clearstr=['delete(findobj(gcf,''Style'',''pushbutton''));',...
          'delete(findobj(gcf,''Style'',''edit''));',...
          'delete(findobj(gcf,''Type'',''axes''));'];
eval(clearstr);

xx=[0:dx:(nx-1)*dx];zz=[0:dx:(nz-1)*dx];
imagesc(xx,zz,v_syn);
colorbar;
xlabel('Offset (ft)');
ylabel('Depth (ft)');
title('Velocity Model');
text((nx-1)*dx+(nx-1)*dx/670*100,-(nz-1)*dx/20,'ft/sec');

end %switch
