function [dataout]=agc(datain,window,type)

%[dataout]=agc(datain,window,type)
%
%This function will do automatic gain control with a running window equation
%on the traces in datain.
%The size of the sliding window is specified by the parameter 'window' in
%seconds.
%'type' = 1 use absolute values for normalizing
%'type' = 2 use energy values (x^2) for normalizing
%
%DSIsoft ver 1.0
%DSI customized VSP processing software
%
%written by Kristen Beaty Dec. 1997
%last modified January 28, 1998

%Copyright (C) 1998 Seismology and Electromagnetic Section/
%Continental Geosciences Division/Geological Survey of Canada
%
%This library is free software; you can redistribute it and/or
%modify it under the terms of the GNU Library General Public
%License as published by the Free Software Foundation; either
%version 2 of the License, or (at your option) any later version.
%
%This library is distributed in the hope that it will be useful,
%but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%Library General Public License for more details.
%
%You should have received a copy of the GNU Library General Public
%License along with this library; if not, write to the
%Free Software Foundation, Inc., 59 Temple Place - Suite 330,
%Boston, MA  02111-1307, USA.
%
%DSI Consortium
%Continental Geosciences Division
%Geological Survey of Canada
%615 Booth St.
%Ottawa, Ontario
%K1A 0E9
%
%email: dsi@cg.nrcan.gc.ca

disp('[dataout]=agc(datain,window,type)')

dataout=datain;

tstart=datain.fh{9}; %start time in seconds
int=datain.fh{8}; %sampling interval in seconds
samples=datain.fh{7}; %number of points per trace
%convert 'window' from seconds to indexes
w=round(window./int)+1;
pt=round(w/2); %index of point in the centre of the window

if w==samples
 pt=samples;
elseif w>samples %error check
 error('choose a smaller window')
end %if/else

nrec=datain.fh{12}; %number of records in datain

for COUNT=1:nrec
 switch type

  case 1 %absolute values
   fact=sum(abs(datain.dat{COUNT}(1:w,:)))./w;
   factgr=meshgrid(fact,1:pt);
   dataout.dat{COUNT}(1:pt,:)=datain.dat{COUNT}(1:pt,:)./factgr;
   for k=1:samples-w
    fact=fact-abs(datain.dat{COUNT}(k,:))./w+abs(datain.dat{COUNT}(k+w,:))./w;
    dataout.dat{COUNT}(k+pt,:)=datain.dat{COUNT}(k+pt,:)./fact;
   end %for

  case 2 %squared values
   fact=sum(datain.dat{COUNT}(1:w,:).*datain.dat{COUNT}(1:w,:))./w;
   factgr=meshgrid(fact,1:pt);
   dataout.dat{COUNT}(i,:)=datain.dat{COUNT}(i,:)./factgr;
   for k=1:samples-w
    fact=fact-datain.dat{COUNT}(k,:).*datain.dat{COUNT}(k,:)./w;
    fact=fact+datain.dat{COUNT}(k+w,:).*datain.dat{COUNT}(k+w,:)./w;
    dataout.dat{COUNT}(k+pt,:)=datain.dat{COUNT}(k+pt,:)./fact;
   end %for
 end %case
 i=k+1:samples;
 factgr=meshgrid(fact,i);
 dataout.dat{COUNT}(i,:)=datain.dat{COUNT}(i,:)./factgr;
end %loop over records
