function [matfile]=su2matp(filename,pickp,picks,crosswire,platform);

%function [matfile]=su2matp(filename,pickp,picks,crosswire,platform)
%
%The funcion converts a SU formatted file into official DSI format
%The filename must be specified within sigle quotation marks
%The file identified by filename should contain all the SU files to
%be processed, and each on a separate line (without quotation marks). 
%
%INPUT
%filename  - filename containing su filename(s).
%            Must be enclosed in single quotes.
%crosswire - name of crosswire file.  Must be enclosed in single quotes.
%platform  = 'l' for little-endian (PC) files
%	     'b' for big-endian (Unix) files
%pickp     - file containing filenames for p wave pickings
%picks     - file containing filenames for s wave pickings
%Note: Sometimes, the scale for coordinates could be incorrect, caution 
%      must be taken.
%

disp('[matfile]=su2mat(filename,crosswire,platform)')

filestr=readascii(filename);
filestrp=readascii(pickp);
filestrs=readascii(picks);

NHEAD=240; 
tr=0; %total number of traces in file

platform=lower(platform);
crs=load(crosswire);
for c=1:size(crs,1)
 if crs(c,2)==1
  crsformat{c}='char';
 elseif crs(c,2)==2
  crsformat{c}='int16';
 elseif crs(c,2)==4
  crsformat{c}='float32';
 else
  crsformat{c}='int32';
 end %if
end %for

%initialize file herders
for i=1:64
 matfile.fh{i}=0;
end %for

%looping over the list of files
%opening the SU file
permission='r';
for j=1:length(filestr)

  fid=fopen(filestr{j},permission,platform);
  fidp=fopen(filestrp{j},permission,platform); % p picking
  fids=fopen(filestrs{j},permission,platform); % s picking

  fseek(fid,0,1);
  endoffile=ftell(fid);

  % find the number of traces in the record
   fseek(fid,114,-1); % number of samples in this trace
   ns=fread(fid,1,'int16');
   fseek(fid,116,-1); % sample interval, in microseconds
   dt=fread(fid,1,'int16')/1000000; % in seconds
   ntr= endoffile/(NHEAD+ns*4); 
%   while ~(ftell(fid)==endoffile)
%     ntr=ntr+1;
%     buff=(NHEAD+ns*4)*ntr
%     fseek(fid,buff,-1);
%   end


   matfile.th{j}=zeros(64,ntr);  %initializing trace headers
   matfile.dat{j}=zeros(ns,ntr); %initialize data matrix

  %looping over the trace
   for i=1:ntr
    buff=(NHEAD+ns*4)*(i-1);

  % modefiied by Min Zhou, 03/01/00*****************
  % use crosswire file to read in trace headers
    for c=1:size(crs,1)
     fseek(fid,buff+crs(c,1)-1,-1);
     matfile.th{j}(crs(c,5),i)=fread(fid,1,crsformat{c})*crs(c,3)+crs(c,4);
    end %for
  % modefiied by Min Zhou, 03/01/00*****************

  % fseek(fid,buff+8,-1); % FFID
  % matfile.th{j}(2,i)=fread(fid,1,'int32');

  % fseek(fid,buff+12,-1); % original trace #
  % matfile.th{j}(1,i)=fread(fid,1,'int32');

  % fseek(fid,buff+20,-1); % CDP #
  % matfile.th{j}(3,i)=fread(fid,1,'int32');

  % fseek(fid,buff+28,-1); % kill flag
  % matfile.th{j}(6,i)=fread(fid,1,'int16');

  % read in locations of the sources and receivers
  % fseek(fid,buff+40,-1); % receiver group elevation from sea level
  % gelev=fread(fid,1,'int32');
  % fseek(fid,buff+44,-1); % source elevation from sea level
  % selev=fread(fid,1,'int32');
  % fseek(fid,buff+68,-1); %scale factor for elevations
  % scalel=fread(fid,1,'int16'); % >0, multiply; <0 divide
  % matfile.th{j}(39,i)=gelev*10^scalel;
  % matfile.th{j}(33,i)=selev*10^scalel;
    
  % fseek(fid,buff+70,-1); %scale factor for coordinate
  % scalco=fread(fid,1,'int16');
  % fseek(fid,buff+72,-1); % X source coordinate
  % matfile.th{j}(30,i)=fread(fid,1,'int32')*10^scalco;
  % fseek(fid,buff+76,-1); % Y source coordinate
  % matfile.th{j}(32,i)=fread(fid,1,'int32')*10^scalco;
  % fseek(fid,buff+80,-1); % X receiver coordinate
  % matfile.th{j}(36,i)=fread(fid,1,'int32')*10^scalco;
  % fseek(fid,buff+84,-1); % Y receiver coordinate
  % matfile.th{j}(38,i)=fread(fid,1,'int32')*10^scalco;

  % read trace data
    fseek(fid,buff+NHEAD,-1); % read data
    matfile.dat{j}(:,i)=fread(fid,ns,'float32');
   end %for i

   matfile.th{j}(12,1)=ntr; %number of traces this record.
   matfile.th{j}(13,:)=1:ntr; %trace sequential number
   deadtr=find(matfile.th{j}(6,:)==2);
   matfile.th{j}(6,deadtr)=-1; %convert segy kill flags to DSI kill flags
   tr=tr+ntr; %number of traces read so far
   fclose(fid);

  % read the pickings
   line=fgets(fidp);
   line=fgets(fids);
   ppick=fscanf(fidp,'%f',[3,inf]);
   spick=fscanf(fids,'%f',[3,inf]);
   fclose(fids);
   fclose(fidp);
   matfile.th{j}(15,:)=ppick(2,18:5:268);  %put p picking at offset 15
   matfile.th{j}(16,:)=spick(2,18:5:268);  %put s picking at offset 16
end %for j

   %initializing the matfile file headers
   matfile.fh{1}=tr;
   matfile.fh{7}=ns;
   matfile.fh{8}=dt;
   matfile.fh{9}=0.0;
   matfile.fh{10}=(ns-1)*dt;
   matfile.fh{12}=length(filestr);
   matfile.fh{13}=ntr;
