function [matfile]=su2matspec(filename);

%function [matfile]=su2matspec(filename)
%
%The funcion converts a SU formatted file into official DSI format
%The filename must be specified within sigle quotation marks
%The file identified by filename should contain all the SU to be processed
%each on a separate line

filestr=readascii(filename);
load loc.dat;
NHEAD=240; 
tr=0; %total nuber of traces in file

%looping over the list of files
%opening the SU file
for j=1:length(filestr)
  eval(['fid=fopen(filestr{j});']);
  fseek(fid,0,1);
  endoffile=ftell(fid);

  % find the number of traces in the record
   fseek(fid,114,-1); % number of samples in this trace
   ns=fread(fid,1,'int16');
   fseek(fid,116,-1); % sample interval, in microseconds
   dt=fread(fid,1,'int16')/1000000; % in seconds
   ntr= endoffile/(NHEAD+ns*4); 
%   while ~(ftell(fid)==endoffile)
%     ntr=ntr+1;
%     buff=(NHEAD+ns*4)*ntr
%     fseek(fid,buff,-1);
%   end


   matfile.th{j}=zeros(64,ntr);  %initializing trace headers
   matfile.dat{j}=zeros(ns,ntr); %initialize data matrix

  %looping over the trace
   for i=1:ntr
    buff=(NHEAD+ns*4)*(i-1);
    fseek(fid,buff+8,-1); % FFID
    matfile.th{j}(2,i)=fread(fid,1,'int32');

    fseek(fid,buff+12,-1); % original trace #
    matfile.th{j}(1,i)=fread(fid,1,'int32');

    fseek(fid,buff+20,-1); % CDP #
    matfile.th{j}(3,i)=fread(fid,1,'int32');

    fseek(fid,buff+28,-1); % kill flag
    matfile.th{j}(6,i)=fread(fid,1,'int16');

  % read in locations of the sources and receivers
    fseek(fid,buff+40,-1); % receiver group elevation from sea level
    gelev=fread(fid,1,'int32');
    fseek(fid,buff+44,-1); % source elevation from sea level
    selev=fread(fid,1,'int32');
    fseek(fid,buff+68,-1); %scale factor for elevations
    scalel=fread(fid,1,'int16'); % >0, multiply; <0 divide
    matfile.th{j}(39,i)=gelev*10^scalel;
    matfile.th{j}(33,i)=selev*10^scalel;
    
    fseek(fid,buff+70,-1); %scale factor for coordinate
    scalco=fread(fid,1,'int16');
    fseek(fid,buff+72,-1); % X source coordinate
    matfile.th{j}(30,i)=fread(fid,1,'int32')*10^scalco;
    fseek(fid,buff+76,-1); % Y source coordinate
    matfile.th{j}(32,i)=fread(fid,1,'int32')*10^scalco;
    fseek(fid,buff+80,-1); % X receiver coordinate
    matfile.th{j}(36,i)=fread(fid,1,'int32')*10^scalco;
    fseek(fid,buff+84,-1); % Y receiver coordinate
    matfile.th{j}(38,i)=fread(fid,1,'int32')*10^scalco;

    matfile.th{j}(30,i)=loc((j-1)*48+i,1);
    matfile.th{j}(32,i)=loc((j-1)*48+i,2);
    matfile.th{j}(33,i)=loc((j-1)*48+i,3);
    matfile.th{j}(36,i)=loc((j-1)*48+i,4);
    matfile.th{j}(38,i)=loc((j-1)*48+i,5);
    matfile.th{j}(39,i)=loc((j-1)*48+i,6);

    fseek(fid,buff+NHEAD,-1); % read data
    matfile.dat{j}(:,i)=fread(fid,ns,'float32');
   end %for i
   matfile.th{j}(12,1)=ntr; %number of traces this record.
   matfile.th{j}(13,:)=1:ntr; %trace sequential number
   deadtr=find(matfile.th{j}(6,:)==2);
   matfile.th{j}(6,deadtr)=-1; %convert segy kill flags to DSI kill flags
   tr=tr+ntr; %number of traces read so far
   fclose(fid);
end %for j

   %initializing the matfile file headers
   matfile.fh{1}=tr;
   matfile.fh{7}=ns;
   matfile.fh{8}=dt;
   matfile.fh{9}=0.0;
   matfile.fh{10}=(ns-1)*dt;
   matfile.fh{12}=length(filestr);
   matfile.fh{13}=ntr;
