function [dataout]=anisocor(datain,pickoff,nsec,corang)
% 
% This function correct the possible time differences cause by
% anisotropy of the medium. First arrivals are corrected to a 
% homogenious medium with the same shot-receiver configuration.
% INPUT:
% datain:     DSI format data
% pickoff:    Offset in the trace head where the travel times are stored
% nsec:       User chosed # of sections of angles to devide (vel,angle), 
%             mean values of velocities and angles in each section are used 
%             to find best fit ellipse for anisotropic correction.
% corang:     User chosed angle in best fit ellipse to calculate the 
%             reference homogenuous velocity. (In Degree). 
%         =0  horizontal
%         =90 vertical
% By Min Zhou, 11/31/99
%

if nargin<4
  pickoff=15;
  nsec=20;
  corang=0;
end %if, set the default value for pickoff, nsec,corang

corang=corang*pi/180;  % degree to rad.

% see if the data has been fitted to 2-D plane
fid=fopen('transform.mat','r');

if fid==-1
 [dataout,s2d,r2d]=fit2d(datain,1,pickoff); %fit to 2-d plan
 % Read in picktime
 nrec=datain.fh{12};
 pick=[];
 for rec=1:nrec %loop over records
  pick=[pick dataout.th{rec}(pickoff,:)];
 end
 pick=pick';

else

 fclose(fid);
 dataout=datain;
 [loc,pck]=readdata(datain,1,pickoff);
 pick=pck(:,1);   % picking in column vector

%do the rotation to get 2-D location
 load transform;
 old=[loc(:,1)-xyz0(1) loc(:,2)-xyz0(2) loc(:,3)-xyz0(3)]';
 new=trans*old;
 xnew=new(1,:)'; ynew=new(2,:)';
 clear trans xyz0

 ln=length(xnew);
  s2d=[xnew(1:ln/2,:) ynew(1:ln/2,:)]; 
  r2d=[xnew(ln/2+1:ln,:) ynew(ln/2+1:ln,:)];
end %if fid

%slope of shot line
[lx m]=size(s2d);

angl=atan((r2d(:,2)-s2d(:,2))./(r2d(:,1)-s2d(:,1))); %angles w.r.t horizontal;
dis=sqrt((r2d(:,2)-s2d(:,2)).^2+(r2d(:,1)-s2d(:,1)).^2);

% check if there is any missing picking time
empty=find(pick==0);
if ~isempty(empty)
  error('There are traces missing time picking!');
  return;
end %if
avel=dis./pick;

% devide the (vel,angle) into nsec sections
vel=avel; agl_sec=angl;
amax=max(angl);amin=min(angl);
da=(amax-amin)/nsec;
av=zeros(nsec,1); an=zeros(nsec,1); % initialize vectors for mean (vel,ang) pairs
for ia=1:nsec
  ang_ia=(angl<=amin+ia*da & angl>=amin+(ia-1)*da);
  av(ia)=sum(vel.*ang_ia)/sum(ang_ia);  % average velocity in ia'th section
  an(ia)=amin+(ia-0.5)*da;                % mean angle
end %for

% Best fit ellips in means of least square 
[theta0,e,b]=inverfit([av,an],0.1);
angl1=(-pi:pi/100:pi)';
fitrho=afit(angl1,theta0,e,b);
polar(angl,avel,'+r');
hold on
polar(angl1,fitrho,'.b');

% Make corrections to the pickings
% The reference homogenuous average velocity is also chosen by user in terms
% of an angle with respect to horizontal direction.
avelc=afit(corang,theta0,e,b);  % reference average velocity for correction;
pick=pick.*(avel./avelc); % corrected travel time tc=t*(avel/avelc);
trcount=0;
for i=1:nrec 
  trcountend=trcount+dataout.th{i}(12,1);
  dataout.th{i}(pickoff,:)=pick(trcount+1:trcountend)';
  trcount=trcountend;
end %for 
polar(angl,avelc.*ones(size(angl)),'og');
legend('+r','Before correction','.b','Best fit Ellipse',...
       'og','After correction');
hold off

