function con2d(datain,coordform,offsetpick)
%
% This function read the 3D locations of shots & receivers
% and their first arrival times from DSI format file.
% Then converts these information to 2D configuration of shot
% and receiver pairs.
% 
% coordform: indicate the coordinate system
%       =1 : cartesian coordinate system
%       =2 : spherical coordinate system
% Here only coordform=1 is considered
%
% There are two ascii output files: coord.temp & timepick.dat
% coord.temp:   data file for the inversion part.
% timepick.dat: 2D shot and receiver coordinates, first arrival 
%               in one line for one shot-receiver pair.
% By Min Zhou, 08/10/99
%

if nargin<3
 coordform=1;
 offsetpick=15;
end

% The place of coordinate information in DSI format trace headers.
coordform=1;
if coordform==1
cor=[30 32 33 36 38 39];
elseif coordform==2
cor=[29 31 33 35 37 39];
else
  error('Unknown coordinate system.');
  return;
end

% Read out the coordinates of the sources and receivers.
nrec=datain.fh{12};
ntrc=datain.fh{13};
sx=[];sy=[];sz=[];
gx=[];gy=[];gz=[];
pickp=[];pickq=[];

%see if the location has been fitted to a plane
fd=fopen('transform.mat','r');
if fd==-1
  [datain,nscoord,nrcoord]=fit2d(datain,coordform,offsetpick);
else
  fclose(fd);
end %if

%find the offset of the shots and receivers w.r.t the first shot
trcount=0; %set the trace counter
for rec=1:nrec % loop over records
  trcount=trcount+datain.th{rec}(12,1);
  pickp=[pickp datain.th{rec}(offsetpick,:)]; %picking
  pickq=[pickq datain.th{rec}(11,:)]; %pick quality
  sx=[sx datain.th{rec}(cor(1),:)]; % shot X
  sy=[sy datain.th{rec}(cor(2),:)]; % shot Y
  sz=[sz datain.th{rec}(cor(3),:)]; % shot elevation
  gx=[gx datain.th{rec}(cor(4),:)]; % receiver X
  gy=[gy datain.th{rec}(cor(5),:)]; % receiver Y
  gz=[gz datain.th{rec}(cor(6),:)]; % receiver elevation
end % for rec=1:nrec

  x=[sx gx]';
  y=[sy gy]';
  z=[sz gz]';
  pick=[pickp' pickq'];

  load transform;
  old=[x'-xyz0(1);y'-xyz0(2);z'-xyz0(3)]; % plan equation is: n(1)x-y+n(2)z+n(3)=0
  new=trans*old;
  xnew=new(1,:)'; ynew=new(2,:)';
  clear xyz0 trans

%output 'timepick.dat'
  ln=length(xnew);
  if ln~=2*trcount  % see if the trace # is the same as shot-receiver pairs
   error('Trace number does not match that of the shot-receiver pairs');
  end %if
  nscoord=[xnew(1:ln/2,:) ynew(1:ln/2,:)];  
  nrcoord=[xnew(ln/2+1:ln,:) ynew(ln/2+1:ln,:)]; 
  timepick=[nscoord nrcoord pick(:,1)];
  save timepick.dat timepick -ascii;

%output 'coord.temp'
  fid=fopen('coord.temp','w');
  fprintf(fid,'%d %10.4f %10.4f %10.4f  ',...
     nrec,min(xnew),max(xnew),max(xnew)-min(xnew));
  fprintf(fid,'%10.4f\n %10.4f %10.4f  %d\n',...
     min(ynew),max(ynew),max(ynew)-min(ynew),datain.fh{13});
  tcount=1;
  for j=1:nrec
   ntrc=datain.th{j}(12,1);
   fprintf(fid,'%d %10.4f %10.4f %d\n',j,nscoord(tcount,1:2),ntrc);
   tcount=tcount+ntrc;
  end %for
  for j=1:length(nrcoord(:,1))
   fprintf(fid,'%10.4f %10.4f %14.7f  %d\n',nrcoord(j,1:2),pick(j,1:2));
  end %for
  fclose(fid);
  h=uicontrol(findobj('name','QCfitplot'),'Style','pushbutton',...
    'String','Data file ''coord.temp'' has been saved...',...
    'backgroundcolor',[1 1 1],...
    'foregroundcolor',[1 0 0],'position',[100 400 500 50],...
    'horizontalalignment','center','fontsize',18);
  pause(2);
  delete(h);
