function [dataout,nscoord,nrcoord]=fit2dcsg(datain,coordform,pickoff)

%
% Fit the sources and receivers to a 2-D plane. 
% Coordform: indicate the coordinate system
%       =1:  cartesian coordinate system
%       =2:  spherical coordinate system
% now only the program only works for cartesian coordinate.
% nscoord,nrcoord :shot and geophone (x,y) coordinates expression
%

% Min Zhou, 08/10/99

if nargin<3
 coordform=1;
 pickoff=15;
end

% The place of coordinate information in DSI format trace headers. 
coordform=1;
if coordform==1
cor=[30 32 33 36 38 39];
elseif coordform==2
cor=[29 31 33 35 37 39];
else
  error('Unknown coordinate system.');
  return;
end

% Read out the coordinates of the sources and receivers.
dataout=datain;
nrec=datain.fh{12};
ntrc=datain.fh{13};
sx=[];sy=[];sz=[];
gx=[];gy=[];gz=[];

%find the offset of the shots and receivers w.r.t the first shot
s0x=datain.th{1}(cor(1),1);
s0y=datain.th{1}(cor(2),1);
s0z=datain.th{1}(cor(3),1);
%[s0x s0y s0z]
trcount=0; %set the trace counter 
for rec=1:nrec % loop over records
  trcount=trcount+datain.th{rec}(12,1);
  sx=[sx datain.th{rec}(cor(1),:)-s0x]; % shot X
  sy=[sy datain.th{rec}(cor(2),:)-s0y]; % shot Y
  sz=[sz datain.th{rec}(cor(3),:)-s0z]; % shot elevation
  gx=[gx datain.th{rec}(cor(4),:)-s0x]; % receiver X
  gy=[gy datain.th{rec}(cor(5),:)-s0y]; % receiver Y
  gz=[gz datain.th{rec}(cor(6),:)-s0z]; % receiver elevation
end % for rec=1:nrec

% find the best fit plane with these points, assume this 
% plan is approx. in x-z plan. Ax+By+Cz+D=0, with B~=0.
  xx=[sx gx]';
  yy=[sy gy]';
  zz=[sz gz]';
  g=[xx zz ones(size(xx))]; dd=yy;
  n=inv(g'*g)*g'*dd; % solve gn=dd in least square sense

% The equation for the best fit plane is:
% Ax+By+Cz+D=0
  a=n(1); b=-1;c=n(2);d=n(3);
  sc=a*a+b*b+c*c;

% Find the projections of these points on the plane 
  
for rec=1:nrec % loop over records
  sx0=datain.th{rec}(cor(1),:)-s0x; % shot X
  sy0=datain.th{rec}(cor(2),:)-s0y; % shot Y
  sz0=datain.th{rec}(cor(3),:)-s0z; % shot elevation
  gx0=datain.th{rec}(cor(4),:)-s0x; % receiver X
  gy0=datain.th{rec}(cor(5),:)-s0y; % receiver Y
  gz0=datain.th{rec}(cor(6),:)-s0z; % receiver elevation
  t0=datain.th{rec}(pickoff,:); % pick time

  % fit to the plane
  sxf=((b*b+c*c)*sx0-a.*(b*sy0+c*sz0+d))./sc+s0x;
  syf=((a*a+c*c)*sy0-b.*(a*sx0+c*sz0+d))./sc+s0y;
  szf=((a*a+b*b)*sz0-c.*(a*sx0+b*sy0+d))./sc+s0z;
  gxf=((b*b+c*c)*gx0-a.*(b*gy0+c*gz0+d))./sc+s0x;
  gyf=((a*a+c*c)*gy0-b.*(a*gx0+c*gz0+d))./sc+s0y;
  gzf=((a*a+b*b)*gz0-c.*(a*gx0+b*gy0+d))./sc+s0z;
 
  % shot-receiver distance
  rf=sqrt((sxf-gxf).^2+(syf-gyf).^2+(szf-gzf).^2); 
  r0=sqrt((sx0-gx0).^2+(sy0-gy0).^2+(sz0-gz0).^2);
  t1=rf./r0.*t0;             % pick time
  dataout.th{rec}(cor(1),:)=sxf; % shot X
  dataout.th{rec}(cor(2),:)=syf; % shot Y
  dataout.th{rec}(cor(3),:)=szf; % shot elevation
  dataout.th{rec}(cor(4),:)=gxf; % receiver X
  dataout.th{rec}(cor(5),:)=gyf; % receiver Y
  dataout.th{rec}(cor(6),:)=gzf; % receiver elevation
  dataout.th{rec}(pickoff,:)=t1;  % pick time
end % for rec=1:nrec

% fit to plane for xx, yy, zz
  x=((b*b+c*c)*xx-a.*(b*yy+c*zz+d))./sc;
  y=((a*a+c*c)*yy-b.*(a*xx+c*zz+d))./sc;
  z=((a*a+b*b)*zz-c.*(a*xx+b*yy+d))./sc;
% plan equation is: n(1)x-y+n(2)z+n(3)=0
% find the shot or receiver with smallest y coordinates
  [y1,i]=min(y);x1=x(i);z1=z(i);
% new coordinate origin in 2D plan
  z0=min(z);
  x0=(x1-n(1)*(n(2)*z0-y1+n(3)))/(n(1)*n(1)+1);
  y0=n(1)*x0+n(2)*z0+n(3);
[x1 y1 z1]
[x0 y0 z0]
% if y0>min(y),y1=min(y);x1=x(i);z1=z(i); 
%  if y0>min(y) 
%   [y1,i]=max(y);x1=x(i);z1=z(i);
%  x0=(x1-n(1)*(n(2)*z0-y1+n(3)))/(n(1)*n(1)+1);
%  y0=n(1)*x0+n(2)*z0+n(3);
%  end %if 

% y axis is from (x0,y0,z0) to (x1,y1,z1), x axis has the equation
% n(1)*x-y+n(2)*z0+n(3)=0
% get the coordinates of shots and receivers in the new cood-system
  r0=sqrt((x1-x0)^2+(y1-y0)^2+(z1-z0)^2);
  ynew=((x-x0).*(x1-x0)+(y-y0).*(y1-y0)+(z-z0).*(z1-z0))./r0;
  xnew=real(sqrt((x-x0).^2+(y-y0).^2+(z-z0).^2-ynew.^2)); 
% when xnew=0, sometimes complex number may appear

  ln=length(xnew);
  if ln~=2*trcount  % see if the trace # is the same as shot-receiver pairs
   error('Trace number does not match that of the shot-receiver pairs');
  end %if
  nscoord=[xnew(1:ln/2,:) ynew(1:ln/2,:)];  
  nrcoord=[xnew(ln/2+1:ln,:) ynew(ln/2+1:ln,:)]; 
