function [coord,pickpq]=readdata(datain,coordform,pickoff)

%
% read shot-receiver coordinates, picking and pick quality
% from DSI format data
%
% Coordform: indicate the coordinate system
%       =1:  cartesian coordinate system
%       =2:  spherical coordinate system
% now only the program only works for cartesian coordinate.
%
% coord :   shot and geophone location (sx sy sz; rx ry rz) 
%           where (sx sy sz) shot location, s* are column vectors
%                 (rx ry rz) reciever location, r* are column vectors
% pickpq:   picking and pick quality in clolumn vectors (pickp pickq)
%
% By Min Zhou, 08/10/99

if nargin<3
 coordform=1;
 pickoff=15;
end

% The place of coordinate information in DSI format trace headers. 
coordform=1;
if coordform==1
cor=[30 32 33 36 38 39];
elseif coordform==2
cor=[29 31 33 35 37 39];
else
  error('Unknown coordinate system.');
  return;
end

% Read out the coordinates of the sources and receivers.
nrec=datain.fh{12};
ntrc=datain.fh{13};
sx=[];sy=[];sz=[];
gx=[];gy=[];gz=[];
pickp=[];pickq=[];

%find the offset of the shots and receivers w.r.t the first shot
for rec=1:nrec % loop over records
  pickp=[pickp datain.th{rec}(pickoff,:)]; %picking
  pickq=[pickq datain.th{rec}(11,:)];   % pick quality
  sx=[sx datain.th{rec}(cor(1),:)]; % shot X
  sy=[sy datain.th{rec}(cor(2),:)]; % shot Y
  sz=[sz datain.th{rec}(cor(3),:)]; % shot elevation
  gx=[gx datain.th{rec}(cor(4),:)]; % receiver X
  gy=[gy datain.th{rec}(cor(5),:)]; % receiver Y
  gz=[gz datain.th{rec}(cor(6),:)]; % receiver elevation
end % for rec=1:nrec
  xx=[sx gx]';
  yy=[sy gy]';
  zz=[sz gz]';
  coord=[xx yy zz];
  pickpq=[pickp' pickq'];
