function [pqcsg,pqcrg]=zmqc(csg,crg,pickcrit,pickoffset);
%
% set pick quality to trace according to the difference of the picking time
% in the crg and csg set.
% input pickcrit in ms, default pickcrit=0.2ms
% dtime<=pickcrit/2,          pickquality=1;
% pickcrit/2<dtime<=pickcrit, pickquality=2;
% dtime>pickcrit,             pickquality=3;
% write pickquality to trace header 11.

% By Min Zhou, 08/10/99
%load csg; load crg;
pqcsg=csg; pqcrg=crg;

if nargin<4
  pickcrit=0.2;
  pickoffset=15;
end 

pickcrit=pickcrit/1000;  % Cutoff criterion for traveltime residual in seconds
% Check if the total number of traces is the same
if csg.fh{1}~=crg.fh{1}
 error(['CSG and CRG do not have the same number of traces.']);
 return;
end

nrec_csg=csg.fh{12};
nrec_crg=crg.fh{12};

for rec_csg=1:nrec_csg %loop over records
  trc_csg=csg.th{rec_csg}(12,1);
  if trc_csg~=nrec_crg;
   error('Number of receivers does not match in CSG and CRG.');
   return;
  end %if
  pick_csg(rec_csg,:)=csg.th{rec_csg}(pickoffset,:);
end %for rec_csg=1:nrec_csg

for rec_crg=1:nrec_crg %loop over records
  trc_crg=crg.th{rec_crg}(12,1);
  if trc_crg~=nrec_csg;
   error('Number of shots does not match in CSG and CRG.');
   return;
  end %if
  pick_crg(rec_crg,:)=crg.th{rec_crg}(pickoffset,:);
end %for rec_crg=1:nrec_crg
  pick_q=abs(pick_csg-pick_crg');
  pick1=pick_q<=pickcrit/2;
  pick2=(pick_q<=pickcrit&pick_q>pickcrit/2).*2;
  pick3=(pick_q>pickcrit).*3;
  pickq=pick1+pick2+pick3;

% write the pickquality to the trace headers
  
for rec_csg=1:nrec_csg %loop over csg
  trc_csg=csg.th{rec_csg}(12,1);
  if trc_csg~=nrec_crg;
   error('Number of receivers does not match in CSG and CRG.');
   return;
  end %if
  pqcsg.th{rec_csg}(11,:)=pickq(rec_csg,:);
end %for rec_csg=1:nrec_csg

for rec_crg=1:nrec_crg %loop over crg
  trc_crg=crg.th{rec_crg}(12,1);
  if trc_crg~=nrec_csg;
   error('Number of receivers does not match in CSG and CRG.');
   return;
  end %if
pqcrg.th{rec_crg}(11,:)=pickq(:,rec_crg);
end %for rec_crg=1:nrec_crg
